/*
 * Copyright (c) 2012, 2017, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package java.util;

import java.util.stream.Collector;

/**
 * A state object for collecting statistics such as count, min, max, sum, and
 * average.
 *
 * <p>This class is designed to work with (though does not require)
 * {@linkplain java.util.stream streams}. For example, you can compute
 * summary statistics on a stream of doubles with:
 * <pre> {@code
 * DoubleSummaryStatistics stats = doubleStream.collect(DoubleSummaryStatistics::new,
 *                                                      DoubleSummaryStatistics::accept,
 *                                                      DoubleSummaryStatistics::combine);
 * }</pre>
 *
 * <p>{@code DoubleSummaryStatistics} can be used as a
 * {@linkplain java.util.stream.Stream#collect(Collector) reduction}
 * target for a {@linkplain java.util.stream.Stream stream}. For example:
 *
 * <pre> {@code
 * DoubleSummaryStatistics stats = people.stream()
 *     .collect(Collectors.summarizingDouble(Person::getWeight));
 *}</pre>
 *
 * This computes, in a single pass, the count of people, as well as the minimum,
 * maximum, sum, and average of their weights.
 *
 * @implNote This implementation is not thread safe. However, it is safe to use
 * {@link java.util.stream.Collectors#summarizingDouble(java.util.function.ToDoubleFunction)
 * Collectors.summarizingDouble()} on a parallel stream, because the parallel
 * implementation of {@link java.util.stream.Stream#collect Stream.collect()}
 * provides the necessary partitioning, isolation, and merging of results for
 * safe and efficient parallel execution.
 * @since 1.8
 */

@SuppressWarnings({"unchecked", "deprecation", "all"})
public class DoubleSummaryStatistics implements java.util.function.DoubleConsumer {

/**
 * Constructs an empty instance with zero count, zero sum,
 * {@code Double.POSITIVE_INFINITY} min, {@code Double.NEGATIVE_INFINITY}
 * max and zero average.
 */

public DoubleSummaryStatistics() { throw new RuntimeException("Stub!"); }

/**
 * Constructs a non-empty instance with the specified {@code count},
 * {@code min}, {@code max}, and {@code sum}.
 *
 * <p>If {@code count} is zero then the remaining arguments are ignored and
 * an empty instance is constructed.
 *
 * <p>If the arguments are inconsistent then an {@code IllegalArgumentException}
 * is thrown.  The necessary consistent argument conditions are:
 * <ul>
 *   <li>{@code count >= 0}</li>
 *   <li>{@code (min <= max && !isNaN(sum)) || (isNaN(min) && isNaN(max) && isNaN(sum))}</li>
 * </ul>
 * @apiNote
 * The enforcement of argument correctness means that the retrieved set of
 * recorded values obtained from a {@code DoubleSummaryStatistics} source
 * instance may not be a legal set of arguments for this constructor due to
 * arithmetic overflow of the source's recorded count of values.
 * The consistent argument conditions are not sufficient to prevent the
 * creation of an internally inconsistent instance.  An example of such a
 * state would be an instance with: {@code count} = 2, {@code min} = 1,
 * {@code max} = 2, and {@code sum} = 0.
 *
 * @param count the count of values
 * @param min the minimum value
 * @param max the maximum value
 * @param sum the sum of all values
 * @throws java.lang.IllegalArgumentException if the arguments are inconsistent
 * @since 10
 */

public DoubleSummaryStatistics(long count, double min, double max, double sum) throws java.lang.IllegalArgumentException { throw new RuntimeException("Stub!"); }

/**
 * Records another value into the summary information.
 *
 * @param value the input value
 */

public void accept(double value) { throw new RuntimeException("Stub!"); }

/**
 * Combines the state of another {@code DoubleSummaryStatistics} into this
 * one.
 *
 * @param other another {@code DoubleSummaryStatistics}
 * @throws java.lang.NullPointerException if {@code other} is null
 */

public void combine(java.util.DoubleSummaryStatistics other) { throw new RuntimeException("Stub!"); }

/**
 * Return the count of values recorded.
 *
 * @return the count of values
 */

public final long getCount() { throw new RuntimeException("Stub!"); }

/**
 * Returns the sum of values recorded, or zero if no values have been
 * recorded.
 *
 * <p> The value of a floating-point sum is a function both of the
 * input values as well as the order of addition operations. The
 * order of addition operations of this method is intentionally
 * not defined to allow for implementation flexibility to improve
 * the speed and accuracy of the computed result.
 *
 * In particular, this method may be implemented using compensated
 * summation or other technique to reduce the error bound in the
 * numerical sum compared to a simple summation of {@code double}
 * values.
 *
 * Because of the unspecified order of operations and the
 * possibility of using differing summation schemes, the output of
 * this method may vary on the same input values.
 *
 * <p>Various conditions can result in a non-finite sum being
 * computed. This can occur even if the all the recorded values
 * being summed are finite. If any recorded value is non-finite,
 * the sum will be non-finite:
 *
 * <ul>
 *
 * <li>If any recorded value is a NaN, then the final sum will be
 * NaN.
 *
 * <li>If the recorded values contain one or more infinities, the
 * sum will be infinite or NaN.
 *
 * <ul>
 *
 * <li>If the recorded values contain infinities of opposite sign,
 * the sum will be NaN.
 *
 * <li>If the recorded values contain infinities of one sign and
 * an intermediate sum overflows to an infinity of the opposite
 * sign, the sum may be NaN.
 *
 * </ul>
 *
 * </ul>
 *
 * It is possible for intermediate sums of finite values to
 * overflow into opposite-signed infinities; if that occurs, the
 * final sum will be NaN even if the recorded values are all
 * finite.
 *
 * If all the recorded values are zero, the sign of zero is
 * <em>not</em> guaranteed to be preserved in the final sum.
 *
 * @apiNote Values sorted by increasing absolute magnitude tend to yield
 * more accurate results.
 *
 * @return the sum of values, or zero if none
 */

public final double getSum() { throw new RuntimeException("Stub!"); }

/**
 * Returns the minimum recorded value, {@code Double.NaN} if any recorded
 * value was NaN or {@code Double.POSITIVE_INFINITY} if no values were
 * recorded. Unlike the numerical comparison operators, this method
 * considers negative zero to be strictly smaller than positive zero.
 *
 * @return the minimum recorded value, {@code Double.NaN} if any recorded
 * value was NaN or {@code Double.POSITIVE_INFINITY} if no values were
 * recorded
 */

public final double getMin() { throw new RuntimeException("Stub!"); }

/**
 * Returns the maximum recorded value, {@code Double.NaN} if any recorded
 * value was NaN or {@code Double.NEGATIVE_INFINITY} if no values were
 * recorded. Unlike the numerical comparison operators, this method
 * considers negative zero to be strictly smaller than positive zero.
 *
 * @return the maximum recorded value, {@code Double.NaN} if any recorded
 * value was NaN or {@code Double.NEGATIVE_INFINITY} if no values were
 * recorded
 */

public final double getMax() { throw new RuntimeException("Stub!"); }

/**
 * Returns the arithmetic mean of values recorded, or zero if no
 * values have been recorded.
 *
 * <p> The computed average can vary numerically and have the
 * special case behavior as computing the sum; see {@link #getSum}
 * for details.
 *
 * @apiNote Values sorted by increasing absolute magnitude tend to yield
 * more accurate results.
 *
 * @return the arithmetic mean of values, or zero if none
 */

public final double getAverage() { throw new RuntimeException("Stub!"); }

/**
 * Returns a non-empty string representation of this object suitable for
 * debugging. The exact presentation format is unspecified and may vary
 * between implementations and versions.
 */

public java.lang.String toString() { throw new RuntimeException("Stub!"); }
}

